@@ -6,7 +6,7 @@
 #
 ###
 #
-#  Copyright (c) 1993 - 97	David Albert Bagley, bagleyd@bigfoot.com
+#  Copyright (c) 1993 - 99	David Albert Bagley, bagleyd@tux.org
 #
 #                   All Rights Reserved
 #
@@ -84,7 +84,7 @@ static void Initialize(Widget w);
 static void CallbackCubes(Widget w, caddr_t clientData, cubesCallbackStruct * callData);
 
 static void PrintRecord(int sizeX, int sizeY, int sizeZ);
-static int  HandleSolved(int counter, int sizeX, int sizeY, int sizeZ);
+static Boolean HandleSolved(int counter, int sizeX, int sizeY, int sizeZ);
 static void InitRecords(void);
 static void ReadRecords(void);
 static void WriteRecords(void);
@@ -113,18 +113,24 @@ Usage(void)
 	(void) fprintf(stderr,
 	     "\t[-geometry [{width}][x{height}][{+-}{xoff}[{+-}{yoff}]]]\n");
 	(void) fprintf(stderr,
-		       "\t[-display [{host}]:[{vs}]]\n");
+	   "\t[-display [{host}]:[{vs}]] [-[no]mono] [-[no]{reverse|rv}]\n");
 	(void) fprintf(stderr,
 		"\t[-{foreground|fg} {color}] [-{background|bg} {color}]\n");
 	(void) fprintf(stderr,
 	 "\t[-{border|bd} {color}] [-brick {color}] [-size{x|y|z} {int}]\n");
 	(void) fprintf(stderr,
-		       "\t[-username {string}]\n");
+		       "\t[-base {int}] [-username {string}]\n");
 	exit(1);
 }
 
 static XrmOptionDescRec options[] =
 {
+	{"-mono", "*cubes.mono", XrmoptionNoArg, "TRUE"},
+	{"-nomono", "*cubes.mono", XrmoptionNoArg, "FALSE"},
+	{"-rv", "*cubes.reverse", XrmoptionNoArg, "TRUE"},
+	{"-reverse", "*cubes.reverse", XrmoptionNoArg, "TRUE"},
+	{"-norv", "*cubes.reverse", XrmoptionNoArg, "FALSE"},
+	{"-noreverse", "*cubes.reverse", XrmoptionNoArg, "FALSE"},
 	{"-fg", "*cubes.Foreground", XrmoptionSepArg, NULL},
 	{"-foreground", "*cubes.Foreground", XrmoptionSepArg, NULL},
 	{"-bg", "*Background", XrmoptionSepArg, NULL},
@@ -135,6 +141,7 @@ static XrmOptionDescRec options[] =
 	{"-sizex", "*cubes.sizeX", XrmoptionSepArg, NULL},
 	{"-sizey", "*cubes.sizeY", XrmoptionSepArg, NULL},
 	{"-sizez", "*cubes.sizeZ", XrmoptionSepArg, NULL},
+	{"-base", "*cubes.base", XrmoptionSepArg, NULL},
 	{"-username", "*cubes.userName", XrmoptionSepArg, NULL}
 };
 
@@ -151,26 +158,28 @@ main(int argc, char **argv)
 	if (argc != 1)
 		Usage();
 
-	XtSetArg(arg[0], XtNiconPixmap,
-		 XCreateBitmapFromData(XtDisplay(toplevel),
-				       RootWindowOfScreen(XtScreen(toplevel)),
+	XtSetArg(arg[0],
+		 XtNiconPixmap, XCreateBitmapFromData(XtDisplay(toplevel),
+				      RootWindowOfScreen(XtScreen(toplevel)),
 			    (char *) cubes_bits, cubes_width, cubes_height));
 	XtSetArg(arg[1], XmNkeyboardFocusPolicy, XmPOINTER);	/* not XmEXPLICIT */
 	XtSetValues(toplevel, arg, 2);
-	panel = XtCreateManagedWidget("panel", xmPanedWindowWidgetClass, toplevel,
-				      NULL, 0);
-	panel2 = XtVaCreateManagedWidget("panel2", xmPanedWindowWidgetClass, panel,
+	panel = XtCreateManagedWidget("panel",
+				xmPanedWindowWidgetClass, toplevel, NULL, 0);
+	panel2 = XtVaCreateManagedWidget("panel2",
+					 xmPanedWindowWidgetClass, panel,
 					 XmNseparatorOn, False,
 					 XmNsashWidth, 1,
-					 XmNsashHeight, 1,
-					 NULL);
+					 XmNsashHeight, 1, NULL);
 
-	rowcol = XtVaCreateManagedWidget("Rowcol", xmRowColumnWidgetClass, panel2,
+	rowcol = XtVaCreateManagedWidget("Rowcol",
+					 xmRowColumnWidgetClass, panel2,
 					 XmNnumColumns, 2,
 					 XmNorientation, XmHORIZONTAL,
-					 XmNpacking, XmPACK_COLUMN,
-					 NULL);
-	XtVaGetValues(rowcol, XmNforeground, &fg, XmNbackground, &bg, NULL);
+					 XmNpacking, XmPACK_COLUMN, NULL);
+	XtVaGetValues(rowcol,
+		      XmNforeground, &fg,
+		      XmNbackground, &bg, NULL);
 	mouseLeftCursor = XCreatePixmapFromBitmapData(XtDisplay(rowcol),
 	      RootWindowOfScreen(XtScreen(rowcol)), (char *) mouse_left_bits,
 				 mouse_left_width, mouse_left_height, fg, bg,
@@ -179,66 +188,76 @@ main(int argc, char **argv)
 	     RootWindowOfScreen(XtScreen(rowcol)), (char *) mouse_right_bits,
 			       mouse_right_width, mouse_right_height, fg, bg,
 				     DefaultDepthOfScreen(XtScreen(rowcol)));
-	XtVaCreateManagedWidget("mouseLeftText", xmLabelGadgetClass, rowcol,
+	XtVaCreateManagedWidget("mouseLeftText",
+				xmLabelGadgetClass, rowcol,
 	    XtVaTypedArg, XmNlabelString, XmRString, "Move brick", 11, NULL);
-	XtVaCreateManagedWidget("mouseLeft", xmLabelGadgetClass, rowcol,
+	XtVaCreateManagedWidget("mouseLeft",
+				xmLabelGadgetClass, rowcol,
 	      XmNlabelType, XmPIXMAP, XmNlabelPixmap, mouseLeftCursor, NULL);
-	XtVaCreateManagedWidget("mouseRightText", xmLabelGadgetClass, rowcol,
+	XtVaCreateManagedWidget("mouseRightText",
+				xmLabelGadgetClass, rowcol,
 	     XtVaTypedArg, XmNlabelString, XmRString, "Randomize", 10, NULL);
-	XtVaCreateManagedWidget("mouseRight", xmLabelGadgetClass, rowcol,
+	XtVaCreateManagedWidget("mouseRight",
+				xmLabelGadgetClass, rowcol,
 	     XmNlabelType, XmPIXMAP, XmNlabelPixmap, mouseRightCursor, NULL);
-	XtVaCreateManagedWidget("movesText", xmLabelGadgetClass, rowcol,
+	XtVaCreateManagedWidget("movesText",
+				xmLabelGadgetClass, rowcol,
 		  XtVaTypedArg, XmNlabelString, XmRString, "Moves", 6, NULL);
-	moves = XtVaCreateManagedWidget("0", xmLabelWidgetClass, rowcol, NULL);
-	XtVaCreateManagedWidget("recordText", xmLabelGadgetClass, rowcol,
+	moves = XtVaCreateManagedWidget("0",
+					xmLabelWidgetClass, rowcol, NULL);
+	XtVaCreateManagedWidget("recordText",
+				xmLabelGadgetClass, rowcol,
 		 XtVaTypedArg, XmNlabelString, XmRString, "Record", 7, NULL);
-	record = XtVaCreateManagedWidget("0", xmLabelWidgetClass, rowcol, NULL);
+	record = XtVaCreateManagedWidget("0",
+					 xmLabelWidgetClass, rowcol, NULL);
 
-	rowcol2 = XtVaCreateManagedWidget("Rowcol2", xmRowColumnWidgetClass, panel2,
-					  NULL);
-	XtVaGetValues(rowcol2, XmNforeground, &fg, XmNbackground, &bg, NULL);
-	blockX = XtVaCreateManagedWidget("blockX", xmScaleWidgetClass, rowcol2,
+	rowcol2 = XtVaCreateManagedWidget("Rowcol2",
+				       xmRowColumnWidgetClass, panel2, NULL);
+	XtVaGetValues(rowcol2,
+		      XmNforeground, &fg,
+		      XmNbackground, &bg, NULL);
+	blockX = XtVaCreateManagedWidget("blockX",
+					 xmScaleWidgetClass, rowcol2,
 		      XtVaTypedArg, XmNtitleString, XmRString, "Blocks X", 8,
 					 XmNminimum, MINCUBES,
 					 XmNmaximum, MAXCUBES,
 					 XmNvalue, MINCUBES,
 					 XmNshowValue, True,
-					 XmNorientation, XmHORIZONTAL,
-					 NULL);
-	XtAddCallback(blockX, XmNvalueChangedCallback, (XtCallbackProc) BlockXSlider,
-		      (XtPointer) NULL);
-	blockY = XtVaCreateManagedWidget("blockY", xmScaleWidgetClass, rowcol2,
+					 XmNorientation, XmHORIZONTAL, NULL);
+	XtAddCallback(blockX,
+		      XmNvalueChangedCallback, (XtCallbackProc) BlockXSlider, (XtPointer) NULL);
+	blockY = XtVaCreateManagedWidget("blockY",
+					 xmScaleWidgetClass, rowcol2,
 		      XtVaTypedArg, XmNtitleString, XmRString, "Blocks Y", 8,
 					 XmNminimum, MINCUBES,
 					 XmNmaximum, MAXCUBES,
 					 XmNvalue, MINCUBES,
 					 XmNshowValue, True,
-					 XmNorientation, XmHORIZONTAL,
-					 NULL);
-	XtAddCallback(blockY, XmNvalueChangedCallback, (XtCallbackProc) BlockYSlider,
-		      (XtPointer) NULL);
-	blockZ = XtVaCreateManagedWidget("blockZ", xmScaleWidgetClass, rowcol2,
+					 XmNorientation, XmHORIZONTAL, NULL);
+	XtAddCallback(blockY,
+		      XmNvalueChangedCallback, (XtCallbackProc) BlockYSlider, (XtPointer) NULL);
+	blockZ = XtVaCreateManagedWidget("blockZ",
+					 xmScaleWidgetClass, rowcol2,
 		      XtVaTypedArg, XmNtitleString, XmRString, "Blocks Z", 8,
 					 XmNminimum, MINCUBES,
 					 XmNmaximum, MAXCUBES,
 					 XmNvalue, MINCUBES,
 					 XmNshowValue, True,
-					 XmNorientation, XmHORIZONTAL,
-					 NULL);
-	XtAddCallback(blockZ, XmNvalueChangedCallback, (XtCallbackProc) BlockZSlider,
-		      (XtPointer) NULL);
+					 XmNorientation, XmHORIZONTAL, NULL);
+	XtAddCallback(blockZ,
+		      XmNvalueChangedCallback, (XtCallbackProc) BlockZSlider, (XtPointer) NULL);
 	message = XtVaCreateManagedWidget("Play Cubes! (use mouse or keypad)",
-					  xmLabelWidgetClass, rowcol2,
-					  NULL);
+					  xmLabelWidgetClass, rowcol2, NULL);
 
-	cubes = XtCreateManagedWidget("cubes", cubesWidgetClass, panel, NULL,
-				      0);
-	XtAddCallback(cubes, XtNselectCallback, (XtCallbackProc) CallbackCubes,
-		      (XtPointer) NULL);
+	cubes = XtCreateManagedWidget("cubes",
+				      cubesWidgetClass, panel, NULL, 0);
+	XtAddCallback(cubes,
+	XtNselectCallback, (XtCallbackProc) CallbackCubes, (XtPointer) NULL);
 	Initialize(cubes);
 	XtRealizeWidget(toplevel);
-	XGrabButton(XtDisplay(cubes), AnyButton, AnyModifier, XtWindow(cubes),
-		TRUE, ButtonPressMask | ButtonMotionMask | ButtonReleaseMask,
+	XGrabButton(XtDisplay(cubes), (unsigned int) AnyButton, AnyModifier,
+		    XtWindow(cubes), TRUE,
+		    (unsigned int) (ButtonPressMask | ButtonMotionMask | ButtonReleaseMask),
 		    GrabModeAsync, GrabModeAsync, XtWindow(cubes),
 		    XCreateFontCursor(XtDisplay(cubes), XC_crosshair));
 	XtMainLoop();
@@ -257,14 +276,12 @@ Initialize(Widget w)
 	String      username;
 
 	XtVaSetValues(w,
-		      XtNstart, FALSE,
-		      NULL);
+		      XtNstart, False, NULL);
 	XtVaGetValues(w,
 		      XtNuserName, &username,
 		      XtNsizeX, &sizeX,
 		      XtNsizeY, &sizeY,
-		      XtNsizeZ, &sizeZ,
-		      NULL);
+		      XtNsizeZ, &sizeZ, NULL);
 	if (sizeX <= MAXCUBES)
 		XmScaleSetValue(blockX, sizeX);
 	if (sizeY <= MAXCUBES)
@@ -292,8 +309,7 @@ CallbackCubes(Widget w, caddr_t clientData, cubesCallbackStruct * callData)
 	XtVaGetValues(w,
 		      XtNsizeX, &sizeX,
 		      XtNsizeY, &sizeY,
-		      XtNsizeZ, &sizeZ,
-		      NULL);
+		      XtNsizeZ, &sizeZ, NULL);
 	(void) strcpy(messageDsp, "");
 	switch (callData->reason) {
 		case CUBES_RESTORE:
@@ -304,14 +320,17 @@ CallbackCubes(Widget w, caddr_t clientData, cubesCallbackStruct * callData)
 			(void) strcpy(messageDsp, "Blocked");
 			break;
 		case CUBES_SPACE:
-			/*(void) strcpy(messageDsp, "Spaces can't move"); *//* Too annoying */
+#if 0
+			/* Too annoying */
+			(void) strcpy(messageDsp, "A space can not slide");
+#endif
 			break;
 		case CUBES_IGNORE:
 			(void) strcpy(messageDsp, "Randomize to start");
 			break;
 		case CUBES_MOVED:
 			movesDsp++;
-			XtSetArg(arg[0], XtNstart, TRUE);
+			XtSetArg(arg[0], XtNstart, True);
 			XtSetValues(w, arg, 1);
 			break;
 		case CUBES_SOLVED:
@@ -319,12 +338,12 @@ CallbackCubes(Widget w, caddr_t clientData, cubesCallbackStruct * callData)
 				(void) sprintf(messageDsp, "Congratulations %s!!", usernameDsp);
 			else
 				(void) strcpy(messageDsp, "Solved!");
-			XtSetArg(arg[0], XtNstart, FALSE);
+			XtSetArg(arg[0], XtNstart, False);
 			XtSetValues(w, arg, 1);
 			break;
 		case CUBES_RANDOMIZE:
 			movesDsp = 0;
-			XtSetArg(arg[0], XtNstart, FALSE);
+			XtSetArg(arg[0], XtNstart, False);
 			XtSetValues(w, arg, 1);
 			break;
 		case CUBES_DEC_X:
@@ -382,12 +401,12 @@ CallbackCubes(Widget w, caddr_t clientData, cubesCallbackStruct * callData)
 				XmScaleSetValue(blockZ, sizeZ);
 			break;
 		case CUBES_COMPUTED:
-			XtSetArg(arg[0], XtNstart, FALSE);
+			XtSetArg(arg[0], XtNstart, False);
 			XtSetValues(w, arg, 1);
 			break;
 		case CUBES_UNDO:
 			movesDsp--;
-			XtSetArg(arg[0], XtNstart, TRUE);
+			XtSetArg(arg[0], XtNstart, True);
 			XtSetValues(w, arg, 1);
 			break;
 	}
@@ -404,12 +423,10 @@ BlockXSlider(Widget w, XtPointer clientData, XmScaleCallbackStruct * cbs)
 	XtVaGetValues(cubes,
 		      XtNsizeX, &oldX,
 		      XtNsizeY, &sizeY,
-		      XtNsizeZ, &sizeZ,
-		      NULL);
+		      XtNsizeZ, &sizeZ, NULL);
 	if (oldX != sizeX) {
 		XtVaSetValues(cubes,
-			      XtNsizeX, sizeX,
-			      NULL);
+			      XtNsizeX, sizeX, NULL);
 		movesDsp = 0;
 		(void) sprintf(buff, "%d", movesDsp);
 		motif_print(moves, buff);
@@ -425,12 +442,10 @@ BlockYSlider(Widget w, XtPointer clientData, XmScaleCallbackStruct * cbs)
 	XtVaGetValues(cubes,
 		      XtNsizeX, &sizeX,
 		      XtNsizeY, &oldY,
-		      XtNsizeZ, &sizeZ,
-		      NULL);
+		      XtNsizeZ, &sizeZ, NULL);
 	if (oldY != sizeY) {
 		XtVaSetValues(cubes,
-			      XtNsizeY, sizeY,
-			      NULL);
+			      XtNsizeY, sizeY, NULL);
 		movesDsp = 0;
 		(void) sprintf(buff, "%d", movesDsp);
 		motif_print(moves, buff);
@@ -446,12 +461,10 @@ BlockZSlider(Widget w, XtPointer clientData, XmScaleCallbackStruct * cbs)
 	XtVaGetValues(cubes,
 		      XtNsizeX, &sizeX,
 		      XtNsizeY, &sizeY,
-		      XtNsizeZ, &oldZ,
-		      NULL);
+		      XtNsizeZ, &oldZ, NULL);
 	if (oldZ != sizeZ) {
 		XtVaSetValues(cubes,
-			      XtNsizeZ, sizeZ,
-			      NULL);
+			      XtNsizeZ, sizeZ, NULL);
 		movesDsp = 0;
 		(void) sprintf(buff, "%d", movesDsp);
 		motif_print(moves, buff);
@@ -476,7 +489,7 @@ PrintRecord(int sizeX, int sizeY, int sizeZ)
 	}
 }
 
-static int
+static      Boolean
 HandleSolved(int counter, int sizeX, int sizeY, int sizeZ)
 {
 	int         i = sizeX - MINCUBES, j = sizeY - MINCUBES, k = sizeZ - MINCUBES;
@@ -495,9 +508,9 @@ HandleSolved(int counter, int sizeX, int sizeY, int sizeZ)
 		(void) strcpy(cubesRecord[k][j][i].name, usernameDsp);
 		WriteRecords();
 		PrintRecord(sizeX, sizeY, sizeZ);
-		return TRUE;
+		return True;
 	}
-	return FALSE;
+	return False;
 }
 
 static void
